@@ -1,18 +1,55 @@
-#[doc = "Reader of register INTFLAGC"]
-pub type R = crate::R<u32, super::INTFLAGC>;
-#[doc = "Writer for register INTFLAGC"]
-pub type W = crate::W<u32, super::INTFLAGC>;
-#[doc = "Register INTFLAGC `reset()`'s with value 0"]
-impl crate::ResetValue for super::INTFLAGC {
-    type Type = u32;
+#[doc = "Register `INTFLAGC` reader"]
+pub struct R(crate::R<INTFLAGC_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<INTFLAGC_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
-#[doc = "Reader of field `CAN0_`"]
-pub type CAN0__R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `CAN0_`"]
+impl From<crate::R<INTFLAGC_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<INTFLAGC_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `INTFLAGC` writer"]
+pub struct W(crate::W<INTFLAGC_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<INTFLAGC_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<INTFLAGC_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<INTFLAGC_SPEC>) -> Self {
+        W(writer)
+    }
+}
+#[doc = "Field `CAN0_` reader - CAN0"]
+pub struct CAN0__R(crate::FieldReader<bool, bool>);
+impl CAN0__R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        CAN0__R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for CAN0__R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `CAN0_` writer - CAN0"]
 pub struct CAN0__W<'a> {
     w: &'a mut W,
 }
@@ -30,13 +67,26 @@ impl<'a> CAN0__W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
-#[doc = "Reader of field `CAN1_`"]
-pub type CAN1__R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `CAN1_`"]
+#[doc = "Field `CAN1_` reader - CAN1"]
+pub struct CAN1__R(crate::FieldReader<bool, bool>);
+impl CAN1__R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        CAN1__R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for CAN1__R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `CAN1_` writer - CAN1"]
 pub struct CAN1__W<'a> {
     w: &'a mut W,
 }
@@ -54,13 +104,26 @@ impl<'a> CAN1__W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
-#[doc = "Reader of field `GMAC_`"]
-pub type GMAC__R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GMAC_`"]
+#[doc = "Field `GMAC_` reader - GMAC"]
+pub struct GMAC__R(crate::FieldReader<bool, bool>);
+impl GMAC__R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        GMAC__R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GMAC__R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GMAC_` writer - GMAC"]
 pub struct GMAC__W<'a> {
     w: &'a mut W,
 }
@@ -78,13 +141,26 @@ impl<'a> GMAC__W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | (((value as u32) & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
         self.w
     }
 }
-#[doc = "Reader of field `TCC2_`"]
-pub type TCC2__R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `TCC2_`"]
+#[doc = "Field `TCC2_` reader - TCC2"]
+pub struct TCC2__R(crate::FieldReader<bool, bool>);
+impl TCC2__R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        TCC2__R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for TCC2__R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `TCC2_` writer - TCC2"]
 pub struct TCC2__W<'a> {
     w: &'a mut W,
 }
@@ -102,13 +178,26 @@ impl<'a> TCC2__W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | (((value as u32) & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
         self.w
     }
 }
-#[doc = "Reader of field `TCC3_`"]
-pub type TCC3__R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `TCC3_`"]
+#[doc = "Field `TCC3_` reader - TCC3"]
+pub struct TCC3__R(crate::FieldReader<bool, bool>);
+impl TCC3__R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        TCC3__R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for TCC3__R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `TCC3_` writer - TCC3"]
 pub struct TCC3__W<'a> {
     w: &'a mut W,
 }
@@ -126,13 +215,26 @@ impl<'a> TCC3__W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | (((value as u32) & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
         self.w
     }
 }
-#[doc = "Reader of field `TC4_`"]
-pub type TC4__R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `TC4_`"]
+#[doc = "Field `TC4_` reader - TC4"]
+pub struct TC4__R(crate::FieldReader<bool, bool>);
+impl TC4__R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        TC4__R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for TC4__R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `TC4_` writer - TC4"]
 pub struct TC4__W<'a> {
     w: &'a mut W,
 }
@@ -150,13 +252,26 @@ impl<'a> TC4__W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | (((value as u32) & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
         self.w
     }
 }
-#[doc = "Reader of field `TC5_`"]
-pub type TC5__R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `TC5_`"]
+#[doc = "Field `TC5_` reader - TC5"]
+pub struct TC5__R(crate::FieldReader<bool, bool>);
+impl TC5__R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        TC5__R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for TC5__R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `TC5_` writer - TC5"]
 pub struct TC5__W<'a> {
     w: &'a mut W,
 }
@@ -174,13 +289,26 @@ impl<'a> TC5__W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | (((value as u32) & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
         self.w
     }
 }
-#[doc = "Reader of field `PDEC_`"]
-pub type PDEC__R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `PDEC_`"]
+#[doc = "Field `PDEC_` reader - PDEC"]
+pub struct PDEC__R(crate::FieldReader<bool, bool>);
+impl PDEC__R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        PDEC__R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for PDEC__R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `PDEC_` writer - PDEC"]
 pub struct PDEC__W<'a> {
     w: &'a mut W,
 }
@@ -198,13 +326,26 @@ impl<'a> PDEC__W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
-#[doc = "Reader of field `AC_`"]
-pub type AC__R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `AC_`"]
+#[doc = "Field `AC_` reader - AC"]
+pub struct AC__R(crate::FieldReader<bool, bool>);
+impl AC__R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        AC__R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for AC__R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `AC_` writer - AC"]
 pub struct AC__W<'a> {
     w: &'a mut W,
 }
@@ -222,13 +363,26 @@ impl<'a> AC__W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | (((value as u32) & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
         self.w
     }
 }
-#[doc = "Reader of field `AES_`"]
-pub type AES__R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `AES_`"]
+#[doc = "Field `AES_` reader - AES"]
+pub struct AES__R(crate::FieldReader<bool, bool>);
+impl AES__R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        AES__R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for AES__R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `AES_` writer - AES"]
 pub struct AES__W<'a> {
     w: &'a mut W,
 }
@@ -246,13 +400,26 @@ impl<'a> AES__W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | (((value as u32) & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
         self.w
     }
 }
-#[doc = "Reader of field `TRNG_`"]
-pub type TRNG__R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `TRNG_`"]
+#[doc = "Field `TRNG_` reader - TRNG"]
+pub struct TRNG__R(crate::FieldReader<bool, bool>);
+impl TRNG__R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        TRNG__R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for TRNG__R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `TRNG_` writer - TRNG"]
 pub struct TRNG__W<'a> {
     w: &'a mut W,
 }
@@ -270,13 +437,26 @@ impl<'a> TRNG__W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | (((value as u32) & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
         self.w
     }
 }
-#[doc = "Reader of field `ICM_`"]
-pub type ICM__R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `ICM_`"]
+#[doc = "Field `ICM_` reader - ICM"]
+pub struct ICM__R(crate::FieldReader<bool, bool>);
+impl ICM__R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        ICM__R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for ICM__R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `ICM_` writer - ICM"]
 pub struct ICM__W<'a> {
     w: &'a mut W,
 }
@@ -294,13 +474,26 @@ impl<'a> ICM__W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | (((value as u32) & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
         self.w
     }
 }
-#[doc = "Reader of field `PUKCC_`"]
-pub type PUKCC__R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `PUKCC_`"]
+#[doc = "Field `PUKCC_` reader - PUKCC"]
+pub struct PUKCC__R(crate::FieldReader<bool, bool>);
+impl PUKCC__R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        PUKCC__R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for PUKCC__R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `PUKCC_` writer - PUKCC"]
 pub struct PUKCC__W<'a> {
     w: &'a mut W,
 }
@@ -318,13 +511,26 @@ impl<'a> PUKCC__W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | (((value as u32) & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
         self.w
     }
 }
-#[doc = "Reader of field `QSPI_`"]
-pub type QSPI__R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `QSPI_`"]
+#[doc = "Field `QSPI_` reader - QSPI"]
+pub struct QSPI__R(crate::FieldReader<bool, bool>);
+impl QSPI__R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        QSPI__R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for QSPI__R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `QSPI_` writer - QSPI"]
 pub struct QSPI__W<'a> {
     w: &'a mut W,
 }
@@ -342,13 +548,26 @@ impl<'a> QSPI__W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | (((value as u32) & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
         self.w
     }
 }
-#[doc = "Reader of field `CCL_`"]
-pub type CCL__R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `CCL_`"]
+#[doc = "Field `CCL_` reader - CCL"]
+pub struct CCL__R(crate::FieldReader<bool, bool>);
+impl CCL__R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        CCL__R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for CCL__R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `CCL_` writer - CCL"]
 pub struct CCL__W<'a> {
     w: &'a mut W,
 }
@@ -366,7 +585,7 @@ impl<'a> CCL__W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | (((value as u32) & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
         self.w
     }
 }
@@ -523,4 +742,30 @@ impl W {
     pub fn ccl_(&mut self) -> CCL__W {
         CCL__W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Peripheral interrupt flag status - Bridge C\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [intflagc](index.html) module"]
+pub struct INTFLAGC_SPEC;
+impl crate::RegisterSpec for INTFLAGC_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [intflagc::R](R) reader structure"]
+impl crate::Readable for INTFLAGC_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [intflagc::W](W) writer structure"]
+impl crate::Writable for INTFLAGC_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets INTFLAGC to value 0"]
+impl crate::Resettable for INTFLAGC_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0
+    }
 }
